@@ -15,6 +15,10 @@ function(object, ..., n.ahead = 10, ci = 0.95, dumvar = NULL){
   ## Retrieval of A in matrix (whole)
   Zdet <- matrix(rep(1, n.ahead), nrow = n.ahead, ncol = 1)
   rownames(Zdet) <- seq(nrow(data.all) + 1, length = n.ahead)
+  if(eval(object$vecm@ecdet) == "trend"){
+    trendf <- seq(obs + p + 1 , length = n.ahead)
+    Zdet <- cbind(Zdet, trendf)
+  }
   if(!is.null(eval(object$vecm@season))){
     season <- eval(object$vecm@season)
     seas.names <- paste("sd", 1:(season-1), sep = "")
